"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UsbDeviceVS = exports.EvamUsbManagerVS = void 0;
const mapNativeJsonToUsbDevice_1 = require("./mapper/mapNativeJsonToUsbDevice");
const mapNativeJsonToUrbInterfaceList_1 = require("./mapper/mapNativeJsonToUrbInterfaceList");
class EvamUsbManagerVS {
    constructor(android) {
        this.android = android;
    }
    getDeviceList() {
        let deviceListString = this.android.getDeviceList();
        return Promise.resolve((0, mapNativeJsonToUsbDevice_1.mapNativeJsonToUsbDeviceList)(this.android, deviceListString));
    }
    hasPermission(device) {
        return Promise.resolve(this.android.hasPermission(device.productId || -1, device.vendorId || -1, device.serialNumber || "invalid"));
    }
    openDevice(device) {
        return device.open();
    }
    requestPermission(filters, callback) {
        let response = this.android.requestPermission(JSON.stringify(filters));
        if (response) {
            callback(undefined, response);
        }
        else {
            window.addEventListener("devicePermission", (e) => {
                // @ts-ignore
                let vendorId = e.detail.vendorId;
                this.getDeviceList().then((devList) => {
                    let device = devList.filter((dev) => dev.vendorId === vendorId);
                    if (device.length > 0) {
                        callback(device[0], `Permission granted`);
                    }
                });
            }, { once: true });
        }
        return Promise.resolve(undefined);
    }
}
exports.EvamUsbManagerVS = EvamUsbManagerVS;
class UsbDeviceVS {
    constructor(android, serialNumber, productId, productName, vendorId, version, classCode, subclassCode, protocolCode) {
        this.serialNumber = serialNumber;
        this.productId = productId;
        this.productName = productName;
        this.vendorId = vendorId;
        this.version = version;
        this.classCode = classCode;
        this.subclassCode = subclassCode;
        this.protocolCode = protocolCode;
        this.android = android;
    }
    claimInterface(interfaceNumber, force) {
        let result = this.android.deviceClaimInterface(this.vendorId || -1, interfaceNumber, force);
        if (result === undefined) {
            return Promise.resolve(undefined);
        }
        else {
            throw Error(result);
        }
    }
    close() {
        let result = this.android.deviceClose(this.vendorId || -1);
        if (result === undefined) {
            return Promise.resolve(undefined);
        }
        else {
            throw Error(result);
        }
    }
    controlTransferIn(requestType, recipient, request, value, index, length, timeout) {
        let result = this.android.deviceControlTransferIn(this.vendorId || -1, requestType, recipient, request, value, index, length, timeout);
        return Promise.resolve(JSON.parse(result));
    }
    controlTransferOut(requestType, recipient, request, value, index, data, timeout) {
        let dataArray = Array.from(data);
        let result = this.android.deviceControlTransferOut(this.vendorId || -1, requestType, recipient, request, value, index, JSON.stringify(dataArray), timeout);
        return Promise.resolve(JSON.parse(result));
    }
    forget() {
        return Promise.resolve(undefined);
    }
    getInterfaces() {
        let interfaceListString = this.android.deviceGetInterfaces(this.vendorId || -1);
        return (0, mapNativeJsonToUrbInterfaceList_1.mapNativeJsonToUsbInterfaceList)(interfaceListString);
    }
    open() {
        let result = this.android.deviceOpen(this.vendorId || -1);
        if (result === undefined) {
            return Promise.resolve(undefined);
        }
        else {
            throw Error(result);
        }
    }
    releaseInterface(interfaceNumber) {
        return Promise.resolve(undefined);
    }
    transferIn(endpointNumber, length, timeout) {
        let result = this.android.deviceTransferIn(this.vendorId || -1, endpointNumber - 1, length, timeout);
        return Promise.resolve(JSON.parse(result));
    }
    transferOut(endpointNumber, data, timeout) {
        let result = this.android.deviceTransferOut(this.vendorId || -1, endpointNumber - 1, JSON.stringify(Array.from(data)), timeout);
        return Promise.resolve(JSON.parse(result));
    }
}
exports.UsbDeviceVS = UsbDeviceVS;
//# sourceMappingURL=EvamUsbManagerVS.js.map